@@ -1,7 +1,8 @@
 import requests
+from evd_sdk_lotr.settings import BASE_URL
 
 class Chapters():
-    base_url = "https://the-one-api.dev/v2/chapter"
+    base_url = f"{BASE_URL}/chapter"
 
     def __init__(self, api_key: str):
         self.api_key = api_key
@@ -41,3 +42,21 @@ class Chapters():
 
         except Exception as e:
             return e
+
+    """
+    Request book chapter by name
+    """
+
+    def get_book_chapter_by_name(self, chapterName):
+        try:
+            url = f"{self.base_url}?chapterName={chapterName}"
+            headers = {
+                'Accept': 'application/json',
+                'Authorization': f"Bearer {self.api_key}"
+            }
+
+            chapter = requests.request("GET", url, headers=headers).json()['docs'][0]
+            return {chapterName: chapter}
+
+        except Exception as e:
+            return e
