@@ -1,7 +1,8 @@
 import requests
+from evd_sdk_lotr.settings import BASE_URL
 
 class Quotes():
-    base_url = "https://the-one-api.dev/v2/quote"
+    base_url = f"{BASE_URL}/quote"
 
     def __init__(self, api_key: str):
         self.api_key = api_key
